@@ -42,7 +42,10 @@ function HomepageHeader() {
       </div>
       <div className={styles.logoContainer}>
         <div className={styles.logoBackground} />
-        <img src={"assets/rio-logo.png"} className={styles.logo} />
+        <video className={styles.logo} autoPlay={true} loop={false} muted={true} playsInline={true} preLoad={true}>
+          <source src={"assets/rio-spinning.mov"} type="video/mp4"/>
+          <source src={"assets/rio-spinning.webm"} type="video/webm"/>
+        </video>
       </div>
     </header>
   );
@@ -52,7 +55,7 @@ export default function Home() {
   return (
     <Layout
       title={title}
-      description="Description will go into a meta tag in <head />"
+      description="A modern terminal for the 21st century."
     >
       <HomepageHeader />
       <main>
