@@ -134,6 +134,11 @@ pub fn default_disable_ctlseqs_alt() -> bool {
     }
 }
 
+#[inline]
+pub fn default_ime_cursor_positioning() -> bool {
+    true
+}
+
 pub fn default_config_file_content() -> String {
     r#"
 # Hide the cursor while typing
@@ -263,6 +268,11 @@ pub fn default_config_file_content() -> String {
 #
 # • decorations - Set window decorations, options: "Enabled", "Disabled", "Transparent", "Buttonless"
 #
+# • colorspace - Set the color space for the window
+#     - "srgb" (default on non-macOS)
+#     - "display-p3" (default on macOS)
+#     - "rec2020"
+#
 # Example:
 # [window]
 # width = 600
@@ -271,6 +281,7 @@ pub fn default_config_file_content() -> String {
 # opacity = 1.0
 # blur = false
 # decorations = "enabled"
+# colorspace = "display-p3"
 
 # Renderer
 #
@@ -310,10 +321,15 @@ pub fn default_config_file_content() -> String {
 # disable-ctlseqs-alt - Disable ctlseqs with ALT keys
 #   - For example: Terminal.app does not deal with ctlseqs with ALT keys
 #
+# ime-cursor-positioning - Enable IME cursor positioning
+#   - When enabled, the IME input popup will appear at the cursor position
+#   - Default is true
+#
 # Example:
 # [keyboard]
 # use-kitty-keyboard-protocol = false
 # disable-ctlseqs-alt = false
+# ime-cursor-positioning = true
 
 # Fonts
 #
@@ -469,8 +485,8 @@ pub fn default_config_file_content() -> String {
 # [bindings]
 # keys = [
 #   { key = "q", with = "super", action = "Quit" },
-#   # Bytes[27, 91, 53, 126] is equivalent to "\x1b[5~"
-#   { key = "home", with = "super | shift", bytes = [27, 91, 53, 126] }
+#   # Send escape sequence to clear screen
+#   { key = "l", with = "control", esc = "\u001b[2J\u001b[H" }
 # ]
 
 # Platform
